@@ -19,9 +19,12 @@
 Middleware provided and used by Horizon.
 """
 
+import datetime
 import json
 import logging
 
+import pytz
+
 from django.conf import settings
 from django.contrib.auth import REDIRECT_FIELD_NAME
 from django.contrib.auth.views import redirect_to_login
@@ -33,6 +36,7 @@ from django.utils import timezone
 
 from horizon import exceptions
 from horizon.utils import functions as utils
+from horizon.utils import http as http_utils
 
 
 LOG = logging.getLogger(__name__)
@@ -43,20 +47,38 @@ class HorizonMiddleware(object):
 
     logout_reason = None
 
-    def process_request(self, request):
+    def __init__(self, get_response):
+        self.get_response = get_response
+
+    def __call__(self, request):
+        self._process_request(request)
+        response = self.get_response(request)
+        response = self._process_response(request, response)
+        return response
+
+    def _process_request(self, request):
         """Adds data necessary for Horizon to function to the request."""
 
         request.horizon = {'dashboard': None,
                            'panel': None,
                            'async_messages': []}
-        if not hasattr(request, "user") or not request.user.is_authenticated():
+        if not hasattr(request, "user") or not request.user.is_authenticated:
             # proceed no further if the current request is already known
             # not to be authenticated
             # it is CRITICAL to perform this check as early as possible
             # to avoid creating too many sessions
             return None
 
-        if request.is_ajax():
+        # Since we know the user is present and authenticated, lets refresh the
+        # session expiry if configured to do so.
+        if settings.SESSION_REFRESH:
+            timeout = settings.SESSION_TIMEOUT
+            token_life = request.user.token.expires - datetime.datetime.now(
+                pytz.utc)
+            session_time = min(timeout, int(token_life.total_seconds()))
+            request.session.set_expiry(session_time)
+
+        if http_utils.is_ajax(request):
             # if the request is Ajax we do not want to proceed, as clients can
             #  1) create pages with constant polling, which can create race
             #     conditions when a page navigation occurs
@@ -69,10 +91,8 @@ class HorizonMiddleware(object):
             settings.SESSION_ENGINE ==
             'django.contrib.sessions.backends.signed_cookies'
         ):
-            max_cookie_size = getattr(
-                settings, 'SESSION_COOKIE_MAX_SIZE', None)
-            session_cookie_name = getattr(
-                settings, 'SESSION_COOKIE_NAME', None)
+            max_cookie_size = settings.SESSION_COOKIE_MAX_SIZE
+            session_cookie_name = settings.SESSION_COOKIE_NAME
             session_key = request.COOKIES.get(session_cookie_name)
             if max_cookie_size is not None and session_key is not None:
                 cookie_size = sum((
@@ -85,8 +105,8 @@ class HorizonMiddleware(object):
                         '%(cookie_size)sB >= %(max_cookie_size)sB. '
                         'You need to configure file-based or database-backed '
                         'sessions instead of cookie-based sessions: '
-                        'http://docs.openstack.org/developer/horizon/topics/'
-                        'deployment.html#session-storage',
+                        'https://docs.openstack.org/horizon/latest/'
+                        'admin/sessions.html',
                         {
                             'user_id': request.session.get(
                                 'user_id', 'Unknown'),
@@ -121,7 +141,7 @@ class HorizonMiddleware(object):
                 return shortcuts.render(request, 'not_authorized.html',
                                         status=403)
 
-            if request.is_ajax():
+            if http_utils.is_ajax(request):
                 response_401 = http.HttpResponse(status=401)
                 response_401['X-Horizon-Location'] = response['location']
                 return response_401
@@ -138,16 +158,16 @@ class HorizonMiddleware(object):
             return shortcuts.redirect(exception.location)
 
     @staticmethod
-    def copy_headers(src, dst, headers):
+    def _copy_headers(src, dst, headers):
         for header in headers:
             dst[header] = src[header]
 
-    def process_response(self, request, response):
+    def _process_response(self, request, response):
         """Convert HttpResponseRedirect to HttpResponse if request is via ajax.
 
         This is to allow ajax request to redirect url.
         """
-        if request.is_ajax() and hasattr(request, 'horizon'):
+        if http_utils.is_ajax(request) and hasattr(request, 'horizon'):
             queued_msgs = request.horizon['async_messages']
             if type(response) == http.HttpResponseRedirect:
                 # Drop our messages back into the session as per usual so they
@@ -180,8 +200,8 @@ class HorizonMiddleware(object):
                 redirect_response['X-Horizon-Location'] = response['location']
                 upload_url_key = 'X-File-Upload-URL'
                 if upload_url_key in response:
-                    self.copy_headers(response, redirect_response,
-                                      (upload_url_key, 'X-Auth-Token'))
+                    self._copy_headers(response, redirect_response,
+                                       (upload_url_key, 'X-Auth-Token'))
                 return redirect_response
             if queued_msgs:
                 # TODO(gabriel): When we have an async connection to the
