@@ -18,7 +18,8 @@
 
   angular
     .module('horizon.framework.util.i18n', [])
-    .factory('horizon.framework.util.i18n.gettext', getText);
+    .factory('horizon.framework.util.i18n.gettext', getText)
+    .factory('horizon.framework.util.i18n.ngettext', nGetText);
 
   getText.$inject = ['$window'];
 
@@ -43,8 +44,8 @@
   function getText($window) {
     // If no global function, revert to just returning given text.
     var gettextFunc = $window.gettext || function (x) {
-        return x;
-      };
+      return x;
+    };
 
     // Eventually, could delete the window gettext references here,
     // or provide an appropriate method.
@@ -52,4 +53,27 @@
       return gettextFunc.apply(this, arguments);
     };
   }
+
+  nGetText.$inject = ['$window'];
+
+  /**
+   * @name horizon.framework.util.i18n.ngettext
+   * @description
+   * Provides a wrapper for translation, using the global 'ngettext'
+   * function if it is present.  Provides a method that
+   * simply returns the input if the expected global 'ngettext' is
+   * not provided.
+   */
+  function nGetText($window) {
+    // If no global function, revert to just returning given text.
+    var nGettextFunc = $window.ngettext || function (x) {
+      return x;
+    };
+
+    // Eventually, could delete the window ngettext references here,
+    // or provide an appropriate method.
+    return function () {
+      return nGettextFunc.apply(this, arguments);
+    };
+  }
 })();
