@@ -31,7 +31,8 @@
         title: "title",
         form: "form",
         schema: "schema",
-        model: "model"
+        model: "model",
+        helpUrl: "help.html"
       };
       ctrl = $controller(
         'horizon.framework.widgets.form.ModalFormController',
@@ -63,6 +64,10 @@
       expect(ctrl.model).toEqual('model');
     });
 
+    it('sets helpUrl on scope', function() {
+      expect(ctrl.helpUrl).toEqual('help.html');
+    });
+
     it('calls modalInstance close on submit', function() {
       spyOn(modalInstance, 'close');
       ctrl.submit(mockEvent, mockSchemaValidForm);
