@@ -1,4 +1,5 @@
 /*
+ * (c) Copyright 2016 Hewlett Packard Enterprise Development Company LP
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
@@ -18,7 +19,10 @@
     .module('horizon.framework.widgets.magic-search')
     .directive('stMagicSearch', stMagicSearch);
 
-  stMagicSearch.$inject = ['$timeout'];
+  stMagicSearch.$inject = [
+    '$timeout',
+    'horizon.framework.widgets.magic-search.events'
+  ];
 
   /**
    * @ngdoc directive
@@ -26,8 +30,9 @@
    * @element
    * @description
    * A directive to make Magic Search be a replacement for st-search.
-   * This directive must be outside of a magic-search and inside a
-   * smart-table. This lets MS drive the same filtering capabilities
+   * This directive must be a peer to st-table and contained within an
+   * hz-magic-search-context in order to receive broadcasts.
+   * This lets MS drive the same filtering capabilities
    * in smart-table that st-search does, including filtering on all
    * columns or a specific column (e.g. a facet filters a column).
    *
@@ -36,30 +41,54 @@
    *
    * @example
    * ```
-   * <st-magic-search>
-   *   <magic-search
-   *     template="/static/framework/widgets/magic-search/magic-search.html"
-   *     strings="filterStrings"
-   *     facets="{{ filterFacets }}">
-   *   </magic-search>
-   * </st-magic-search>
+   *
+   *  var filterFacets = [
+   *  {
+   *    label: gettext('Name'),
+   *    name: 'name',
+   *    singleton: true
+   *  },
+   *  {
+   *    label: gettext('VCPUs'),
+   *    name: 'vcpus',
+   *    singleton: true
+   *  },
+   *  {
+   *    label: gettext('RAM'),
+   *    name: 'ram',
+   *    singleton: true
+   *  },
+   *  {
+   *    label: gettext('Public'),
+   *    name: 'isPublic',
+   *    singleton: true,
+   *    options: [
+   *      { label: gettext('No'), key: false },
+   *      { label: gettext('Yes'), key: true }
+   *    ]
+   *  }];
+   *
+   * <hz-magic-search-context
+   *   filter-facets="filterFacets">
+   *   <hz-magic-search-bar></hz-magic-search-bar>
+   *   <table st-table st-magic-search>
+   *   </table>
+   * </hz-magic-search-context>
    * ```
    */
-  function stMagicSearch($timeout) {
+  function stMagicSearch($timeout, magicSearchEvents) {
     var directive = {
       link: link,
-      require: '^stTable',
-      restrict: 'E',
+      require: 'stTable',
+      restrict: 'A',
       scope: true
     };
     return directive;
 
     function link(scope, element, attr, tableCtrl) {
-      var clientFullTextSearch = (angular.isDefined(scope.clientFullTextSearch)
-                                  ? scope.clientFullTextSearch
-                                  : true);
-
-      scope.currentServerSearchParams = {};
+      scope.currentServerSearchParams = {
+        "magicSearchQuery": ""
+      };
 
       // Generate predicate object from dot notation string
       function setPredObj(predicates, predObj, input) {
@@ -97,17 +126,20 @@
           scope.currentServerSearchParams = serverSearchParams;
 
           if (serverSearchParams.queryStringChanged || serverSearchParams.magicSearchQueryChanged) {
-            scope.$emit('serverSearchUpdated', angular.copy(scope.currentServerSearchParams));
+            scope.$emit(
+              magicSearchEvents.SERVER_SEARCH_UPDATED,
+              angular.copy(scope.currentServerSearchParams)
+            );
           }
         }
       }
 
       // When user types a character, search the table
-      var textSearchWatcher = scope.$on('textSearch', function(event, text) {
+      var textSearchWatcher = scope.$on('textSearch-ms-context', function(event, text) {
         // Timeout needed to prevent
         // $apply already in progress error
         $timeout(function() {
-          if (clientFullTextSearch) {
+          if (scope.clientFullTextSearch) {
             tableCtrl.search(text);
           } else {
             setServerTextSearch(scope, text);
@@ -116,7 +148,7 @@
       });
 
       // When user changes a facet, use API filter
-      var searchUpdatedWatcher = scope.$on('searchUpdated', function(event, query) {
+      var searchUpdatedWatcher = scope.$on('searchUpdated-ms-context', function(event, query) {
         setServerFacetSearch(scope, query);
 
         // clear each time since Smart-Table
