@@ -17,6 +17,7 @@
   'use strict';
 
   var READONLY_PROPERTIES = ['os_hash_algo', 'os_hash_value'];
+  var DUPLICATE_PROPERTIES = ['description'];
 
   angular
     .module('horizon.framework.widgets.metadata.tree')
@@ -41,6 +42,11 @@
         ctrl.item.leaf.required = false;
       }
 
+      if ('item' in ctrl && 'leaf' in ctrl.item &&
+        DUPLICATE_PROPERTIES.includes(ctrl.item.leaf.name)) {
+        delete ctrl.item;
+      }
+
       if ('item' in ctrl && 'leaf' in ctrl.item && ctrl.item.leaf.type === 'array') {
         ctrl.values = ctrl.item.leaf.items.enum.filter(filter).sort();
 
