@@ -19,6 +19,10 @@
     .module('horizon.framework.widgets.table')
     .directive('hzSelectAll', hzSelectAll);
 
+  hzSelectAll.$inject = [
+    'horizon.framework.widgets.table.events'
+  ];
+
   /**
    * @ngdoc directive
    * @name horizon.framework.widgets.table.directive:hzSelectAll
@@ -62,7 +66,7 @@
    * controller.
    *
    */
-  function hzSelectAll() {
+  function hzSelectAll(events) {
     var directive = {
       restrict: 'A',
       require: [ '^hzTable', '^stTable' ],
@@ -79,15 +83,15 @@
       var hzTableCtrl = ctrls[0];
       var stTableCtrl = ctrls[1];
 
-      element.click(clickHandler);
+      element.on('click', clickHandler);
 
       /*
        * watch the table state for changes
        * on sort, filter and pagination
        */
       var unWatchTableState = scope.$watch(function() {
-          return stTableCtrl.tableState();
-        },
+        return stTableCtrl.tableState();
+      },
         updateSelectAll,
         true
       );
@@ -96,7 +100,7 @@
       var unWatchRowsLength = scope.$watch('rows.length', updateSelectAll);
 
       // watch for row selection
-      var unWatchRowSelected = scope.$on('hzTable:rowSelected', updateSelectAll);
+      var unWatchRowSelected = scope.$on(events.ROW_SELECTED, updateSelectAll);
 
       // deregister $watch, $on on destroy
       scope.$on('$destroy', function () {
