@@ -20,6 +20,7 @@ import json
 import logging
 from operator import attrgetter
 import sys
+from urllib import parse
 
 from django.conf import settings
 from django.core import exceptions as core_exceptions
@@ -32,11 +33,10 @@ from django.template.loader import render_to_string
 from django import urls
 from django.utils import encoding
 from django.utils.html import escape
-from django.utils import http
 from django.utils.http import urlencode
 from django.utils.safestring import mark_safe
 from django.utils import termcolors
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import conf
 from horizon import exceptions
@@ -46,6 +46,7 @@ from horizon.tables.actions import BatchAction
 from horizon.tables.actions import FilterAction
 from horizon.tables.actions import LinkAction
 from horizon.utils import html
+from horizon.utils import http as http_utils
 from horizon.utils import settings as utils_settings
 
 
@@ -730,7 +731,7 @@ class Cell(html.HTMLElement):
             # those columns where truncate is False leads to multiple errors
             # in unit tests
             data = getattr(datum, column.name, '') or ''
-            data = encoding.force_text(data)
+            data = encoding.force_str(data)
             if len(data) > column.truncate:
                 self.attrs['data-toggle'] = 'tooltip'
                 self.attrs['title'] = data
@@ -1684,7 +1685,7 @@ class DataTable(object, metaclass=DataTableMetaclass):
                 except Exception:
                     datum = None
                     error = exceptions.handle(request, ignore=True)
-                if request.is_ajax():
+                if http_utils.is_ajax(request):
                     if not error:
                         return HttpResponse(new_row.render())
                     return HttpResponse(status=error.status_code)
@@ -1744,7 +1745,7 @@ class DataTable(object, metaclass=DataTableMetaclass):
         except Exception:
             datum = None
             error = exceptions.handle(request, ignore=True)
-        if request.is_ajax():
+        if http_utils.is_ajax(request):
             if not error:
                 return HttpResponse(cell.render())
             return HttpResponse(status=error.status_code)
@@ -1861,7 +1862,7 @@ class DataTable(object, metaclass=DataTableMetaclass):
 
         The return value will be used as marker/limit-based paging in the API.
         """
-        return http.urlquote_plus(self.get_object_id(self.data[0])) \
+        return parse.quote_plus(self.get_object_id(self.data[0])) \
             if self.data else ''
 
     def get_marker(self):
@@ -1869,7 +1870,7 @@ class DataTable(object, metaclass=DataTableMetaclass):
 
         The return value will be used as marker/limit-based paging in the API.
         """
-        return http.urlquote_plus(self.get_object_id(self.data[-1])) \
+        return parse.quote_plus(self.get_object_id(self.data[-1])) \
             if self.data else ''
 
     def get_prev_pagination_string(self):
