@@ -14,7 +14,6 @@ import datetime
 import functools
 import logging
 
-import django
 from django.conf import settings
 from django.contrib import auth
 from django.contrib.auth.decorators import login_required
@@ -36,12 +35,6 @@ from keystoneauth1 import exceptions as keystone_exceptions
 from openstack_auth import exceptions
 from openstack_auth import forms
 from openstack_auth import plugin
-
-# This is historic and is added back in to not break older versions of
-# Horizon, fix to Horizon to remove this requirement was committed in
-# Juno
-# pylint: disable=unused-import
-from openstack_auth.forms import Login  # noqa:F401
 from openstack_auth import user as auth_user
 from openstack_auth import utils
 
@@ -49,25 +42,15 @@ from openstack_auth import utils
 LOG = logging.getLogger(__name__)
 
 
-if django.VERSION >= (4, 0):
-    CSRF_REASONS = [
-        csrf.REASON_BAD_ORIGIN,
-        csrf.REASON_NO_REFERER,
-        csrf.REASON_BAD_REFERER,
-        csrf.REASON_NO_CSRF_COOKIE,
-        csrf.REASON_CSRF_TOKEN_MISSING,
-        csrf.REASON_MALFORMED_REFERER,
-        csrf.REASON_INSECURE_REFERER,
-    ]
-else:
-    CSRF_REASONS = [
-        csrf.REASON_NO_REFERER,
-        csrf.REASON_BAD_REFERER,
-        csrf.REASON_NO_CSRF_COOKIE,
-        csrf.REASON_BAD_TOKEN,
-        csrf.REASON_MALFORMED_REFERER,
-        csrf.REASON_INSECURE_REFERER
-    ]
+CSRF_REASONS = [
+    csrf.REASON_BAD_ORIGIN,
+    csrf.REASON_NO_REFERER,
+    csrf.REASON_BAD_REFERER,
+    csrf.REASON_NO_CSRF_COOKIE,
+    csrf.REASON_CSRF_TOKEN_MISSING,
+    csrf.REASON_MALFORMED_REFERER,
+    csrf.REASON_INSECURE_REFERER,
+]
 
 
 def get_csrf_reason(reason):
@@ -209,6 +192,10 @@ def login(request):
         region_name = regions.get(login_region)
         request.session['region_endpoint'] = region
         request.session['region_name'] = region_name
+        # Check for a services_region cookie. Fall back to the login_region.
+        services_region = request.COOKIES.get('services_region', region_name)
+        if services_region in request.user.available_services_regions:
+            request.session['services_region'] = services_region
         expiration_time = request.user.time_until_expiration()
         threshold_days = settings.PASSWORD_EXPIRES_WARNING_THRESHOLD_DAYS
         if (expiration_time is not None and
