@@ -38,6 +38,7 @@ from openstack_dashboard.api import keystone
 from openstack_dashboard.api import network
 from openstack_dashboard.api import neutron
 from openstack_dashboard.api import nova
+from openstack_dashboard.api import placement
 from openstack_dashboard.api import swift
 
 
@@ -49,5 +50,6 @@ __all__ = [
     "network",
     "neutron",
     "nova",
+    "placement",
     "swift",
 ]
