@@ -121,7 +121,7 @@ class VolumeBackup(BaseCinderAPIResourceWrapper):
 
     _attrs = ['id', 'name', 'description', 'container', 'size', 'status',
               'created_at', 'volume_id', 'availability_zone', 'snapshot_id',
-              'os-backup-project-attr:project_id']
+              'os-backup-project-attr:project_id', 'fail_reason']
     _volume = None
     _snapshot = None
 
@@ -585,18 +585,22 @@ def volume_backup_get(request, backup_id):
     return VolumeBackup(backup)
 
 
-def volume_backup_list(request):
-    backups, _, __ = volume_backup_list_paged(request, paginate=False)
+def volume_backup_list(request, search_opts=None):
+    backups, _, __ = volume_backup_list_paged(request, paginate=False,
+                                              search_opts=search_opts)
     return backups
 
 
 @profiler.trace
-def volume_backup_list_paged_with_page_menu(request, page_number=1,
+def volume_backup_list_paged_with_page_menu(request, search_opts=None,
+                                            page_number=1,
                                             sort_dir="desc",
                                             all_tenants=False):
     backups = []
     count = 0
     pages_count = 0
+    if search_opts is None:
+        search_opts = {}
     page_size = utils.get_page_size(request)
     c_client = cinderclient(request, '3.45')
 
@@ -605,12 +609,12 @@ def volume_backup_list_paged_with_page_menu(request, page_number=1,
 
     offset = (page_number - 1) * page_size
     sort = 'created_at:' + sort_dir
+    search_opts['all_tenants'] = all_tenants
+    search_opts['offset'] = offset
+    search_opts['with_count'] = True
     bkps, count = c_client.backups.list(limit=page_size,
                                         sort=sort,
-                                        search_opts={
-                                            'with_count': True,
-                                            'offset': offset,
-                                            'all_tenants': all_tenants})
+                                        search_opts=search_opts)
     if not bkps:
         return backups, page_size, count, pages_count
 
@@ -625,7 +629,7 @@ def volume_backup_list_paged_with_page_menu(request, page_number=1,
 
 @profiler.trace
 def volume_backup_list_paged(request, marker=None, paginate=False,
-                             sort_dir="desc"):
+                             sort_dir="desc", search_opts=None):
     has_more_data = False
     has_prev_data = False
     backups = []
@@ -642,13 +646,13 @@ def volume_backup_list_paged(request, marker=None, paginate=False,
         sort = 'created_at:' + sort_dir
         for b in c_client.backups.list(limit=page_size + 1,
                                        marker=marker,
-                                       sort=sort):
+                                       sort=sort, search_opts=search_opts):
             backups.append(VolumeBackup(b))
 
         backups, has_more_data, has_prev_data = update_pagination(
             backups, page_size, marker, sort_dir)
     else:
-        for b in c_client.backups.list():
+        for b in c_client.backups.list(search_opts=search_opts):
             backups.append(VolumeBackup(b))
 
     return backups, has_more_data, has_prev_data
@@ -661,6 +665,7 @@ def volume_backup_create(request,
                          name,
                          description,
                          force=False,
+                         incremental=False,
                          snapshot_id=None):
     # need to ensure the container name is not an empty
     # string, but pass None to get the container name
@@ -671,6 +676,7 @@ def volume_backup_create(request,
         name=name,
         description=description,
         snapshot_id=snapshot_id,
+        incremental=incremental,
         force=force)
     return VolumeBackup(backup)
 
