@@ -11,7 +11,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from django.conf import urls
+
+from django.urls import re_path
 
 urlpatterns = []
 
@@ -20,14 +21,13 @@ urlpatterns = []
 # @register below, and the import the endpoint module in the
 # rest_api/__init__.py module
 def register(view):
-    '''Register API views to respond to a regex pattern (url_regex on the
-    view class).
+    """Register API views to respond to a regex pattern.
 
+    ``url_regex`` on a wrapped view class is used as the regex pattern.
     The view should be a standard Django class-based view implementing an
     as_view() method. The url_regex attribute of the view should be a standard
     Django URL regex pattern.
-    '''
-    p = urls.url(view.url_regex, view.as_view())
-    p.add_prefix('openstack_dashboard.rest_api')
+    """
+    p = re_path(view.url_regex, view.as_view())
     urlpatterns.append(p)
     return view
