@@ -21,6 +21,7 @@ from django import http
 from oslo_serialization import jsonutils
 
 from horizon import exceptions
+from horizon.utils import http as http_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -107,7 +108,7 @@ def ajax(authenticated=True, data_required=False,
         def _wrapped(self, request, *args, **kw):
             if authenticated and not request.user.is_authenticated:
                 return JSONResponse('not logged in', 401)
-            if not request.is_ajax():
+            if not http_utils.is_ajax(request):
                 return JSONResponse('request must be AJAX', 400)
 
             # decode the JSON body if present
