@@ -12,14 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import patterns
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.admin.defaults import views
 
 
-urlpatterns = patterns(
-    'openstack_dashboard.dashboards.admin.defaults.views',
-    url(r'^$', views.IndexView.as_view(), name='index'),
-    url(r'^update_defaults$',
-        views.UpdateDefaultQuotasView.as_view(), name='update_defaults'))
+urlpatterns = [
+    re_path(r'^$', views.IndexView.as_view(), name='index'),
+    re_path(r'^update_defaults$',
+            views.UpdateDefaultQuotasView.as_view(), name='update_defaults'),
+]
