@@ -14,10 +14,12 @@
 #    under the License.
 
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 import horizon
 
+from openstack_dashboard.utils import settings as setting_utils
+
 
 class AdminFloatingIps(horizon.Panel):
     name = _("Floating IPs")
@@ -27,5 +29,11 @@ class AdminFloatingIps(horizon.Panel):
 
     @staticmethod
     def can_register():
-        network_config = getattr(settings, 'OPENSTACK_NEUTRON_NETWORK', {})
-        return network_config.get('enable_router', True)
+        return setting_utils.get_dict_config(
+            'OPENSTACK_NEUTRON_NETWORK', 'enable_router')
+
+    def allowed(self, context):
+        if (('network' in settings.SYSTEM_SCOPE_SERVICES) !=
+                bool(context['request'].user.system_scoped)):
+            return False
+        return super().allowed(context)
