@@ -10,8 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.core.urlresolvers import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.urls import reverse
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -35,7 +35,7 @@ class EvacuateHostForm(forms.SelfHandlingForm):
                                            initial=False, required=False)
 
     def __init__(self, request, *args, **kwargs):
-        super(EvacuateHostForm, self).__init__(request, *args, **kwargs)
+        super().__init__(request, *args, **kwargs)
         initial = kwargs.get('initial', {})
         self.fields['target_host'].choices = \
             self.populate_host_choices(request, initial)
@@ -57,6 +57,11 @@ class EvacuateHostForm(forms.SelfHandlingForm):
             current_host = data['current_host']
             target_host = data['target_host']
             on_shared_storage = data['on_shared_storage']
+            # The target_host value will be an empty string when the target
+            # host wasn't specified. But the evacuate api doesn't allow
+            # an empty string. So set None as the target_host value.
+            if not target_host:
+                target_host = None
             api.nova.evacuate_host(request, current_host,
                                    target_host, on_shared_storage)
 
