@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django.conf import settings
 from django.utils.translation import gettext_lazy as _
 
 import horizon
@@ -30,3 +31,9 @@ class MetadataDefinitions(horizon.Panel):
     @staticmethod
     def can_register():
         return glance.VERSIONS.active >= 2
+
+    def allowed(self, context):
+        if (('image' in settings.SYSTEM_SCOPE_SERVICES) !=
+                bool(context['request'].user.system_scoped)):
+            return False
+        return super().allowed(context)
