@@ -16,8 +16,8 @@ import logging
 
 from django.template import defaultfilters as filters
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import tables
 from horizon.utils import filters as utils_filters
@@ -31,7 +31,7 @@ LOG = logging.getLogger(__name__)
 class DeleteDHCPAgent(tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete DHCP Agent",
             "Delete DHCP Agents",
             count
@@ -39,7 +39,7 @@ class DeleteDHCPAgent(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Deleted DHCP Agent",
             "Deleted DHCP Agents",
             count
