@@ -13,7 +13,7 @@
 #    under the License.
 
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import tables
@@ -24,7 +24,6 @@ from openstack_dashboard.dashboards.project.networks.ports import \
     tables as project_tables
 from openstack_dashboard.dashboards.project.networks.ports.tabs \
     import PortsTab as project_port_tab
-from openstack_dashboard.usage import quotas
 
 
 class DeletePort(project_tables.DeletePort):
@@ -35,18 +34,6 @@ class CreatePort(project_tables.CreatePort):
     url = "horizon:admin:networks:addport"
 
     def allowed(self, request, datum=None):
-        network = self.table._get_network()
-        tenant_id = network.tenant_id
-        usages = quotas.tenant_quota_usages(
-            request, tenant_id=tenant_id, targets=('port', ))
-        if usages.get('port', {}).get('available', 1) <= 0:
-            if "disabled" not in self.classes:
-                self.classes = [c for c in self.classes] + ["disabled"]
-                self.verbose_name = _("Create Port (Quota exceeded)")
-        else:
-            self.verbose_name = _("Create Port")
-            self.classes = [c for c in self.classes if c != "disabled"]
-
         return True
 
 
