@@ -22,10 +22,13 @@ from horizon import exceptions
 from horizon import tables
 
 from openstack_dashboard import api
+from openstack_dashboard.dashboards.admin.networks \
+    import utils as admin_utils
 from openstack_dashboard.dashboards.project.networks \
     import tables as project_tables
 from openstack_dashboard import policy
-from openstack_dashboard.usage import quotas
+from openstack_dashboard.utils import settings as setting_utils
+
 
 LOG = logging.getLogger(__name__)
 
@@ -52,19 +55,6 @@ class CreateSubnet(project_tables.CreateSubnet):
     url = "horizon:admin:networks:createsubnet"
 
     def allowed(self, request, datum=None):
-        usages = quotas.tenant_quota_usages(
-            request, tenant_id=datum.tenant_id, targets=('subnet', ))
-
-        # when Settings.OPENSTACK_NEUTRON_NETWORK['enable_quotas'] = False
-        # usages["subnet'] is empty
-        if usages.get('subnet', {}).get('available', 1) <= 0:
-            if 'disabled' not in self.classes:
-                self.classes = list(self.classes) + ['disabled']
-                self.verbose_name = _('Create Subnet (Quota exceeded)')
-        else:
-            self.verbose_name = _('Create Subnet')
-            self.classes = [c for c in self.classes if c != 'disabled']
-
         return True
 
 
@@ -131,12 +121,9 @@ class NetworksTable(tables.DataTable):
                     "is supported")
             exceptions.handle(self.request, msg)
             del self.columns['availability_zones']
-        try:
-            if not api.neutron.is_extension_supported(request,
-                                                      'dhcp_agent_scheduler'):
-                del self.columns['num_agents']
-        except Exception:
-            msg = _("Unable to check if DHCP agent scheduler "
-                    "extension is supported")
-            exceptions.handle(self.request, msg)
+
+        show_agents_column = setting_utils.get_dict_config(
+            'OPENSTACK_NEUTRON_NETWORK', 'show_agents_column')
+        if not (show_agents_column and
+                admin_utils.is_dhcp_agent_scheduler_supported(request)):
             del self.columns['num_agents']
