@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 import horizon
 
@@ -19,7 +19,7 @@ class Volumes(horizon.Panel):
     name = _("Volumes")
     slug = "volumes"
     permissions = (
-        ('openstack.services.volume', 'openstack.services.volumev2',
+        ('openstack.services.volume',
          'openstack.services.volumev3'),
     )
     policy_rules = (("volume", "context_is_admin"),)
