@@ -17,7 +17,7 @@ import logging
 
 from django.conf import settings
 from django.forms import widgets
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.decorators.debug import sensitive_variables
 import yaml
 
