@@ -12,14 +12,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from django.conf.urls import patterns
-from django.conf.urls import url
+from django.urls import re_path
 
 from openstack_dashboard.dashboards.identity.mappings import views
 
-urlpatterns = patterns(
-    'openstack_dashboard.dashboards.identity.mappings.views',
-    url(r'^$', views.IndexView.as_view(), name='index'),
-    url(r'^(?P<mapping_id>[^/]+)/update/$',
-        views.UpdateView.as_view(), name='update'),
-    url(r'^create/$', views.CreateView.as_view(), name='create'))
+urlpatterns = [
+    re_path(r'^$', views.IndexView.as_view(), name='index'),
+    re_path(r'^(?P<mapping_id>[^/]+)/update/$',
+            views.UpdateView.as_view(), name='update'),
+    re_path(r'^create/$', views.CreateView.as_view(), name='create'),
+]
