@@ -28,7 +28,8 @@
   angular
     .module('horizon.dashboard.identity.domains', [
       'ngRoute',
-      'horizon.dashboard.identity.domains.details'
+      'horizon.dashboard.identity.domains.details',
+      'horizon.dashboard.identity.domains.actions'
     ])
     .constant('horizon.dashboard.identity.domains.resourceType', 'OS::Keystone::Domain')
     .run(run)
@@ -43,8 +44,9 @@
 
   function run(registry, domainService, basePath, domainResourceType) {
     registry.getResourceType(domainResourceType)
-      .setNames(gettext('Domain'), gettext('Domains'))
+      .setNames('Domain', 'Domains', ngettext('Domain', 'Domains', 1))
       .setSummaryTemplateUrl(basePath + 'details/drawer.html')
+      .setDefaultIndexUrl('/identity/domains/')
       .setProperties(domainProperties())
       .setListFunction(domainService.listDomains)
       .tableColumns
