@@ -181,12 +181,15 @@ class BackupsTable(tables.DataTable):
                            status=True,
                            status_choices=STATUS_CHOICES,
                            display_choices=STATUS_DISPLAY_CHOICES)
+    availability_zone = tables.Column("availability_zone",
+                                      verbose_name=_("Availability Zone"))
     volume_name = BackupVolumeNameColumn("name",
                                          verbose_name=_("Volume Name"),
                                          link="horizon:project:volumes:detail")
     snapshot = SnapshotColumn("snapshot",
                               verbose_name=_("Snapshot"),
                               link="horizon:project:snapshots:detail")
+    created_at = tables.Column("created_at", verbose_name=_("Created At"))
 
     def current_page(self):
         return self._meta.current_page()
