@@ -9,7 +9,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+from unittest import mock
 from urllib import parse
 
 from django.conf import settings
@@ -20,6 +20,8 @@ from django.utils.http import urlencode
 from openstack_dashboard import api
 from openstack_dashboard.dashboards.project.backups \
     import tables as backup_tables
+from openstack_dashboard.dashboards.project.backups \
+    import tabs
 from openstack_dashboard.test import helpers as test
 
 
@@ -132,11 +134,13 @@ class VolumeBackupsViewTests(test.TestCase):
         self.assertCountEqual(result, expected_backups)
 
     @test.create_mocks({api.cinder: ('volume_backup_create',
+                                     'volume_backup_list',
                                      'volume_snapshot_list',
                                      'volume_get')})
     def test_create_backup_available(self):
         volume = self.cinder_volumes.first()
         backup = self.cinder_volume_backups.first()
+        self.mock_volume_backup_list.return_value = []
 
         self.mock_volume_get.return_value = volume
         self.mock_volume_backup_create.return_value = backup
@@ -166,17 +170,61 @@ class VolumeBackupsViewTests(test.TestCase):
             backup.name,
             backup.description,
             force=False,
+            incremental=False,
+            snapshot_id=None)
+
+    @test.create_mocks({api.cinder: ('volume_backup_create',
+                                     'volume_backup_list',
+                                     'volume_snapshot_list',
+                                     'volume_get')})
+    def test_create_backup_available_incremental(self):
+        volume = self.cinder_volumes.first()
+        backup = self.cinder_volume_backups.list()[1]
+        prior_backups = [self.cinder_volume_backups.list()[0]]
+        self.mock_volume_backup_list.return_value = prior_backups
+
+        self.mock_volume_get.return_value = volume
+        self.mock_volume_backup_create.return_value = backup
+
+        formData = {'method': 'CreateBackupForm',
+                    'tenant_id': self.tenant.id,
+                    'volume_id': volume.id,
+                    'container_name': backup.container_name,
+                    'name': backup.name,
+                    'incremental': True,
+                    'description': backup.description}
+        url = reverse('horizon:project:volumes:create_backup',
+                      args=[volume.id])
+        res = self.client.post(url, formData)
+
+        self.assertNoFormErrors(res)
+        self.assertMessageCount(error=0, warning=0)
+        self.assertRedirectsNoFollow(res, INDEX_URL)
+        self.mock_volume_snapshot_list.assert_called_once_with(
+            test.IsHttpRequest(),
+            search_opts={'volume_id': volume.id})
+        self.mock_volume_get.assert_called_once_with(test.IsHttpRequest(),
+                                                     volume.id)
+        self.mock_volume_backup_create.assert_called_once_with(
+            test.IsHttpRequest(),
+            volume.id,
+            backup.container_name,
+            backup.name,
+            backup.description,
+            force=False,
+            incremental=True,
             snapshot_id=None)
 
     @test.create_mocks(
         {api.cinder: ('volume_backup_create', 'volume_snapshot_get',
-                      'volume_get')})
+                      'volume_get', 'volume_backup_list')})
     def test_create_backup_from_snapshot_table(self):
         backup = self.cinder_volume_backups.list()[1]
         volume = self.cinder_volumes.list()[4]
         snapshot = self.cinder_volume_snapshots.list()[1]
         self.mock_volume_backup_create.return_value = backup
         self.mock_volume_get.return_value = volume
+        self.mock_volume_backup_list.return_value = []
         self.mock_volume_snapshot_get.return_value = snapshot
         formData = {'method': 'CreateBackupForm',
                     'tenant_id': self.tenant.id,
@@ -202,18 +250,20 @@ class VolumeBackupsViewTests(test.TestCase):
             backup.name,
             backup.description,
             force=False,
+            incremental=False,
             snapshot_id=backup.snapshot_id)
 
     @test.create_mocks(
         {api.cinder: ('volume_backup_create',
                       'volume_snapshot_list',
-                      'volume_get')})
+                      'volume_get', 'volume_backup_list')})
     def test_create_backup_from_snapshot_volume_table(self):
         volume = self.cinder_volumes.list()[4]
         backup = self.cinder_volume_backups.list()[1]
         snapshots = self.cinder_volume_snapshots.list()[1:3]
         self.mock_volume_backup_create.return_value = backup
         self.mock_volume_get.return_value = volume
+        self.mock_volume_backup_list.return_value = []
         self.mock_volume_snapshot_list.return_value = snapshots
         formData = {'method': 'CreateBackupForm',
                     'tenant_id': self.tenant.id,
@@ -242,11 +292,12 @@ class VolumeBackupsViewTests(test.TestCase):
             backup.name,
             backup.description,
             force=False,
+            incremental=False,
             snapshot_id=backup.snapshot_id)
 
     @test.create_mocks(
         {api.cinder: ('volume_backup_create', 'volume_snapshot_list',
-                      'volume_get')})
+                      'volume_get', 'volume_backup_list')})
     def test_create_backup_in_use(self):
         # The third volume in the cinder test volume data is in-use
         volume = self.cinder_volumes.list()[2]
@@ -256,6 +307,7 @@ class VolumeBackupsViewTests(test.TestCase):
         self.mock_volume_get.return_value = volume
         self.mock_volume_backup_create.return_value = backup
         self.mock_volume_snapshot_list.return_value = snapshots
+        self.mock_volume_backup_list.return_value = []
         formData = {'method': 'CreateBackupForm',
                     'tenant_id': self.tenant.id,
                     'volume_id': volume.id,
@@ -281,7 +333,92 @@ class VolumeBackupsViewTests(test.TestCase):
             backup.name,
             backup.description,
             force=True,
-            snapshot_id=None)
+            snapshot_id=None,
+            incremental=False)
+
+    @test.create_mocks(
+        {api.cinder: ('volume_backup_create', 'volume_snapshot_list',
+                      'volume_get', 'volume_backup_list')})
+    def test_create_backup_in_use_incremental(self):
+        volume = self.cinder_volumes.list()[2]
+
+        backup = self.cinder_volume_backups.list()[1]
+        snapshots = []
+        self.mock_volume_get.return_value = volume
+        self.mock_volume_backup_create.return_value = backup
+        self.mock_volume_snapshot_list.return_value = snapshots
+        prior_backups = [self.cinder_volume_backups.list()[0]]
+        self.mock_volume_backup_list.return_value = prior_backups
+        formData = {'method': 'CreateBackupForm',
+                    'tenant_id': self.tenant.id,
+                    'volume_id': volume.id,
+                    'container_name': backup.container_name,
+                    'name': backup.name,
+                    'incremental': True,
+                    'description': backup.description}
+        url = reverse('horizon:project:volumes:create_backup',
+                      args=[volume.id])
+
+        res = self.client.post(url, formData)
+        self.mock_volume_snapshot_list.assert_called_once_with(
+            test.IsHttpRequest(),
+            search_opts={'volume_id': volume.id})
+        self.assertNoFormErrors(res)
+        self.assertMessageCount(error=0, warning=0)
+        self.assertRedirectsNoFollow(res, INDEX_URL)
+        self.mock_volume_get.assert_called_once_with(test.IsHttpRequest(),
+                                                     volume.id)
+        self.mock_volume_backup_create.assert_called_once_with(
+            test.IsHttpRequest(),
+            volume.id,
+            backup.container_name,
+            backup.name,
+            backup.description,
+            force=True,
+            snapshot_id=None,
+            incremental=True)
+
+    @test.create_mocks(
+        {api.cinder: ('volume_backup_create', 'volume_snapshot_list',
+                      'volume_get', 'volume_backup_list')})
+    def test_create_backup_in_use_incremental_set_false(self):
+        volume = self.cinder_volumes.list()[2]
+
+        backup = self.cinder_volume_backups.list()[1]
+        snapshots = []
+        self.mock_volume_get.return_value = volume
+        self.mock_volume_backup_create.return_value = backup
+        self.mock_volume_snapshot_list.return_value = snapshots
+        prior_backups = [self.cinder_volume_backups.list()[0]]
+        self.mock_volume_backup_list.return_value = prior_backups
+        formData = {'method': 'CreateBackupForm',
+                    'tenant_id': self.tenant.id,
+                    'volume_id': volume.id,
+                    'container_name': backup.container_name,
+                    'name': backup.name,
+                    'incremental': False,
+                    'description': backup.description}
+        url = reverse('horizon:project:volumes:create_backup',
+                      args=[volume.id])
+
+        res = self.client.post(url, formData)
+        self.mock_volume_snapshot_list.assert_called_once_with(
+            test.IsHttpRequest(),
+            search_opts={'volume_id': volume.id})
+        self.assertNoFormErrors(res)
+        self.assertMessageCount(error=0, warning=0)
+        self.assertRedirectsNoFollow(res, INDEX_URL)
+        self.mock_volume_get.assert_called_once_with(test.IsHttpRequest(),
+                                                     volume.id)
+        self.mock_volume_backup_create.assert_called_once_with(
+            test.IsHttpRequest(),
+            volume.id,
+            backup.container_name,
+            backup.name,
+            backup.description,
+            force=True,
+            snapshot_id=None,
+            incremental=False)
 
     @test.create_mocks({api.cinder: ('volume_list',
                                      'volume_snapshot_list',
@@ -399,6 +536,38 @@ class VolumeBackupsViewTests(test.TestCase):
         self.mock_volume_get.assert_called_once_with(
             test.IsHttpRequest(), backup.volume_id)
 
+    @test.create_mocks({api.cinder: ('volume_backup_get',
+                                     'volume_get',
+                                     'message_list')})
+    def test_volume_backup_detail_view_with_messages_tab(self):
+
+        backup = self.cinder_volume_backups.first()
+        volume = self.cinder_volumes.first()
+
+        self.mock_volume_backup_get.return_value = backup
+        self.mock_volume_get.return_value = volume
+        messages = [msg for msg in self.cinder_messages.list()
+                    if msg.resource_type == 'VOLUME_BACKUP']
+        self.mock_message_list.return_value = messages
+        url = reverse('horizon:project:backups:detail',
+                      args=[backup.id])
+        detail_view = tabs.BackupDetailTabs(self.request)
+        messages_tab_link = "?%s=%s" % (
+            detail_view.param_name,
+            detail_view.get_tab("messages_tab").get_id())
+        url += messages_tab_link
+        res = self.client.get(url)
+        self.assertTemplateUsed(res, 'horizon/common/_detail.html')
+        self.assertContains(res, messages[0].user_message)
+        self.assertNoMessages()
+        self.mock_volume_backup_get.assert_has_calls([
+            mock.call(test.IsHttpRequest(), backup.id),
+        ])
+        search_opts = {'resource_type': 'volume_backup',
+                       'resource_uuid': backup.id}
+        self.mock_message_list.assert_called_once_with(
+            test.IsHttpRequest(), search_opts=search_opts)
+
     @test.create_mocks({api.cinder: ('volume_list',
                                      'volume_backup_restore')})
     def test_restore_backup(self):
