@@ -16,8 +16,8 @@
 import logging
 
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import tables
 
@@ -55,17 +55,17 @@ class AddAllowedAddressPair(policy.PolicyTargetMixin, tables.LinkAction):
 class DeleteAllowedAddressPair(tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
-            u"Delete",
-            u"Delete",
+        return ngettext_lazy(
+            "Delete",
+            "Delete",
             count
         )
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
-            u"Deleted address pair",
-            u"Deleted address pairs",
+        return ngettext_lazy(
+            "Deleted address pair",
+            "Deleted address pairs",
             count
         )
 
@@ -81,13 +81,13 @@ class DeleteAllowedAddressPair(tables.DeleteAction):
 
         return policy_target
 
-    def delete(self, request, ip_address):
+    def delete(self, request, obj_id):
         try:
             port_id = self.table.kwargs['port_id']
             port = api.neutron.port_get(request, port_id)
             pairs = port.get('allowed_address_pairs', [])
             pairs = [pair for pair in pairs
-                     if pair['ip_address'] != ip_address]
+                     if pair.id != obj_id]
             pairs = [pair.to_dict() for pair in pairs]
             api.neutron.port_update(request, port_id,
                                     allowed_address_pairs=pairs)
