@@ -18,8 +18,8 @@ from neutronclient.common import exceptions as neutron_exceptions
 
 from django.urls import reverse
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import exceptions
 from horizon import tables
@@ -59,17 +59,17 @@ class SubnetPolicyTargetMixin(policy.PolicyTargetMixin):
 class DeleteSubnet(SubnetPolicyTargetMixin, tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
-            u"Delete Subnet",
-            u"Delete Subnets",
+        return ngettext_lazy(
+            "Delete Subnet",
+            "Delete Subnets",
             count
         )
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
-            u"Deleted Subnet",
-            u"Deleted Subnets",
+        return ngettext_lazy(
+            "Deleted Subnet",
+            "Deleted Subnets",
             count
         )
 
