@@ -21,8 +21,8 @@ from collections import OrderedDict
 
 from django.urls import reverse
 from django.urls import reverse_lazy
+from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy
-from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -98,7 +98,7 @@ class IndexView(tables.DataTableView):
                 # Translators: The usage is "<UUID of ext_net> (Not Found)"
                 gateway_info['network'] = pgettext_lazy(
                     'External network not found',
-                    u'%s (Not Found)') % ext_net_id
+                    '%s (Not Found)') % ext_net_id
 
 
 class DetailView(tabs.TabbedTableView):
