@@ -17,8 +17,8 @@ import functools
 from django.conf import settings
 from django.template import defaultfilters
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import exceptions
 from horizon import tables
@@ -34,7 +34,7 @@ class DeleteGroup(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Security Group",
             "Delete Security Groups",
             count
@@ -42,7 +42,7 @@ class DeleteGroup(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Deleted Security Group",
             "Deleted Security Groups",
             count
@@ -115,6 +115,20 @@ class SecurityGroupsTable(tables.DataTable):
     security_group_id = tables.Column("id",
                                       verbose_name=_("Security Group ID"))
     description = tables.Column("description", verbose_name=_("Description"))
+    shared = tables.Column("shared", verbose_name=_("Shared"))
+
+    def __init__(self, request, *args, **kwargs):
+        super().__init__(request, *args, **kwargs)
+        try:
+            is_shared_supported = api.neutron.is_extension_supported(
+                self.request, 'security-groups-shared-filtering')
+        except Exception:
+            exceptions.handle(
+                self.request,
+                _('Failed to check if shared field is supported.'))
+            is_shared_supported = False
+        if not is_shared_supported:
+            del self.columns['shared']
 
     def sanitize_id(self, obj_id):
         return filters.get_int_or_uuid(obj_id)
@@ -156,7 +170,7 @@ class DeleteRule(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Delete Rule",
             "Delete Rules",
             count
@@ -164,7 +178,7 @@ class DeleteRule(policy.PolicyTargetMixin, tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             "Deleted Rule",
             "Deleted Rules",
             count
