@@ -151,6 +151,8 @@
                 {id: '4', container_format: 'raw', properties: {}, name: 'raw_image'},
                 {id: '5', container_format: 'ami', properties: {image_type: 'image'}},
                 {id: '6', container_format: 'raw', properties: {image_type: 'image'}},
+                {id: '11', container_format: 'raw', properties: {image_type: ''}},
+                {id: '12', container_format: 'raw', properties: {block_device_mapping: '[]'}},
                 // The following images are considered as "snapshot" sources.
                 {id: '7', container_format: 'ami',
                  properties: {block_device_mapping: '[{"source_type": "snapshot"}]'}},
@@ -392,6 +394,9 @@
              name_or_id: 'raw_image'},
             {id: '5', container_format: 'ami', properties: {image_type: 'image'}, name_or_id: '5'},
             {id: '6', container_format: 'raw', properties: {image_type: 'image'}, name_or_id: '6'},
+            {id: '11', container_format: 'raw', properties: {image_type: ''}, name_or_id: '11'},
+            {id: '12', container_format: 'raw', properties: {block_device_mapping: '[]'},
+             name_or_id: '12'},
             {id: '10', container_format: 'raw', properties: {image_type: 'image'}, name_or_id: '10',
              visibility: 'community'},
           ];
@@ -551,6 +556,13 @@
           expect(model.newInstanceSpec.hide_create_volume).toBe(true);
         });
 
+        it('should default user_data based on setting', function() {
+          settings.OPENSTACK_SERVER_DEFAULT_USER_DATA = 'default-data';
+          model.initialize(true);
+          scope.$apply();
+          expect(model.newInstanceSpec.default_user_data).toBe('default-data');
+        });
+
         it('should not set availability zone if the zone list is empty', function () {
           spyOn(novaApi, 'getAvailabilityZones').and.callFake(function () {
             var deferred = $q.defer();
@@ -883,7 +895,7 @@
         // This is here to ensure that as people add/change items, they
         // don't forget to implement tests for them.
         it('has the right number of properties', function() {
-          expect(Object.keys(model.newInstanceSpec).length).toBe(22);
+          expect(Object.keys(model.newInstanceSpec).length).toBe(23);
         });
 
         it('sets availability zone to null', function() {
@@ -910,6 +922,10 @@
           expect(model.newInstanceSpec.user_data).toBe('');
         });
 
+        it('sets default user data to an empty string', function() {
+          expect(model.newInstanceSpec.default_user_data).toBe('');
+        });
+
         it('sets disk config to AUTO', function() {
           expect(model.newInstanceSpec.disk_config).toBe('AUTO');
         });
