@@ -15,7 +15,7 @@
 from django.conf import settings
 from django.forms import ValidationError
 from django import http
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.views.decorators.debug import sensitive_variables
 
 from horizon import exceptions
