@@ -22,17 +22,17 @@
   deleteImageService.$inject = [
     '$q',
     'horizon.app.core.openstack-service-api.glance',
-    'horizon.app.core.openstack-service-api.userSession',
     'horizon.app.core.openstack-service-api.policy',
+    'horizon.framework.util.actions.action-result.service',
     'horizon.framework.util.i18n.gettext',
     'horizon.framework.util.q.extensions',
     'horizon.framework.widgets.modal.deleteModalService',
     'horizon.framework.widgets.toast.service',
-    'horizon.app.core.images.events'
+    'horizon.app.core.images.resourceType'
   ];
 
-  /**
-   * @ngDoc factory
+  /*
+   * @ngdoc factory
    * @name horizon.app.core.images.actions.delete-image.service
    *
    * @Description
@@ -44,19 +44,17 @@
   function deleteImageService(
     $q,
     glance,
-    userSessionService,
     policy,
+    actionResultService,
     gettext,
     $qExtensions,
     deleteModal,
     toast,
-    events
+    imagesResourceType
   ) {
-    var scope, context, deleteImagePromise;
     var notAllowedMessage = gettext("You are not allowed to delete images: %s");
 
     var service = {
-      initScope: initScope,
       allowed: allowed,
       perform: perform
     };
@@ -65,17 +63,29 @@
 
     //////////////
 
-    function initScope(newScope) {
-      scope = newScope;
-      context = { successEvent: events.DELETE_SUCCESS };
-      deleteImagePromise = policy.ifAllowed({rules: [['image', 'delete_image']]});
-    }
-
-    function perform(items) {
+    function perform(items, newScope) {
+      var scope = newScope;
+      var context = { };
       var images = angular.isArray(items) ? items : [items];
       context.labels = labelize(images.length);
       context.deleteEntity = deleteImage;
       return $qExtensions.allSettled(images.map(checkPermission)).then(afterCheck);
+
+      function checkPermission(image) {
+        return {promise: allowed(image), context: image};
+      }
+
+      function afterCheck(result) {
+        var outcome = $q.reject().catch(angular.noop);  // Reject the promise by default
+        if (result.fail.length > 0) {
+          toast.add('error', getMessage(notAllowedMessage, result.fail));
+          outcome = $q.reject(result.fail).catch(angular.noop);
+        }
+        if (result.pass.length > 0) {
+          outcome = deleteModal.open(scope, result.pass.map(getEntity), context).then(createResult);
+        }
+        return outcome;
+      }
     }
 
     function allowed(image) {
@@ -84,30 +94,25 @@
       if (image) {
         return $q.all([
           notProtected(image),
-          deleteImagePromise,
-          userSessionService.isCurrentProject(image.owner),
+          policy.ifAllowed({ rules: [['image', 'delete_image']] }),
           notDeleted(image)
         ]);
-      }
-      else {
+      } else {
         return policy.ifAllowed({ rules: [['image', 'delete_image']] });
       }
     }
 
-    function checkPermission(image) {
-      return {promise: allowed(image), context: image};
-    }
-
-    function afterCheck(result) {
-      var outcome = $q.reject();  // Reject the promise by default
-      if (result.fail.length > 0) {
-        toast.add('error', getMessage(notAllowedMessage, result.fail));
-        outcome = $q.reject(result.fail);
-      }
-      if (result.pass.length > 0) {
-        outcome = deleteModal.open(scope, result.pass.map(getEntity), context);
-      }
-      return outcome;
+    function createResult(deleteModalResult) {
+      // To make the result of this action generically useful, reformat the return
+      // from the deleteModal into a standard form
+      var actionResult = actionResultService.getActionResult();
+      deleteModalResult.pass.forEach(function markDeleted(item) {
+        actionResult.deleted(imagesResourceType, getEntity(item).id);
+      });
+      deleteModalResult.fail.forEach(function markFailed(item) {
+        actionResult.failed(imagesResourceType, getEntity(item).id);
+      });
+      return actionResult.result;
     }
 
     function labelize(count) {
