@@ -19,7 +19,15 @@
 
   describe('horizon.app.core.images edit image controller', function() {
 
-    var controller, $scope, $q, settingsCall, $timeout;
+    function policyIfAllowed() {
+      return {
+        then: function(callback) {
+          callback({allowed: true});
+        }
+      };
+    }
+
+    var controller, $scope, $q, settingsCall, $timeout, policy;
 
     ///////////////////////
 
@@ -35,6 +43,9 @@
       $timeout = _$timeout_;
 
       controller = $injector.get('$controller');
+
+      policy = $injector.get('horizon.app.core.openstack-service-api.policy');
+      spyOn(policy, 'ifAllowed').and.callFake(policyIfAllowed);
     }));
 
     function createController() {
@@ -57,19 +68,12 @@
     }
 
     it('should have options for visibility and protected', function() {
-      setImagePromise({id: '1', container_format: 'bare', is_public: false, properties: []});
-      var ctrl = createController();
-
-      expect(ctrl.imageVisibilityOptions.length).toEqual(2);
-      expect(ctrl.imageProtectedOptions.length).toEqual(2);
-    });
-
-    it('should map is_public', function() {
-      setImagePromise({id: '1', container_format: 'bare', is_public: false, properties: []});
+      setImagePromise({id: '1', container_format: 'bare', visibility: 'shared', properties: []});
       var ctrl = createController();
       $timeout.flush();
 
-      expect(ctrl.image.visibility).toEqual('private');
+      expect(ctrl.imageVisibilityOptions.length).toEqual(4);
+      expect(ctrl.imageProtectedOptions.length).toEqual(2);
     });
 
     it('reads the data format settings', function() {
@@ -87,14 +91,14 @@
         id: '1',
         container_format: 'bare',
         disk_format: 'ova',
-        is_public: true,
+        visibility: 'private',
         properties: []
       });
       var ctrl = createController();
       $timeout.flush();
 
       expect(ctrl.image.disk_format).toEqual('ova');
-      expect(ctrl.image.visibility).toEqual('public');
+      expect(ctrl.image.visibility).toEqual('private');
     });
 
     it('should set local image_format to docker when container is docker', function() {
@@ -133,5 +137,14 @@
       expect(ctrl.image.container_format).toEqual('ari');
     });
 
+    it('should set container to ovf when disk format is vhd', function() {
+      setImagePromise({id: '1', disk_format: 'vhd', container_format: '',
+        is_public: false, properties: []});
+      var ctrl = createController();
+      $timeout.flush();
+
+      expect(ctrl.image.container_format).toEqual('ovf');
+    });
+
   });
 })();
