@@ -47,6 +47,8 @@
       getResourceTypes: getResourceTypes
     };
 
+    var READONLY_PROPERTIES = ['os_hash_algo', 'os_hash_value'];
+
     return service;
 
     ///////////////
@@ -61,7 +63,7 @@
      */
     function getVersion() {
       return apiService.get('/api/glance/version/')
-        .error(function () {
+        .catch(function onError() {
           toastService.add('error', gettext('Unable to get the Glance service version.'));
         });
     }
@@ -80,7 +82,7 @@
      */
     function getImage(id) {
       return apiService.get('/api/glance/images/' + id + '/')
-        .error(function () {
+        .catch(function onError() {
           toastService.add('error', gettext('Unable to retrieve the image.'));
         });
     }
@@ -121,7 +123,7 @@
      * The minimum memory size required to boot the image. Optional.
      *
      * @param {boolean} image.visibility
-     * values of 'public', 'private', and 'shared' are valid. Required.
+     * values of 'public', 'private', 'shared' and 'community' are valid. Required.
      *
      * @param {boolean} image.protected
      * True if the image is protected, false otherwise. Required.
@@ -171,9 +173,9 @@
 
       function onError(error) {
         if (error && error.data) {
-          throw error;
+          toastService.add('error', error);
         } else {
-          throw gettext('Unable to create the image.');
+          toastService.add('error', gettext('Unable to create the image.'));
         }
       }
 
@@ -217,7 +219,7 @@
      * The minimum memory size required to boot the image. Optional.
      *
      * @param {boolean} image.visibility
-     * Values of 'public', 'private', and 'shared' are valid. Required.
+     * Values of 'public', 'private', 'shared' and 'community' are valid. Required.
      *
      * @param {boolean} image.protected
      * True if the image is protected, false otherwise. Required.
@@ -227,7 +229,7 @@
      */
     function updateImage(image) {
       return apiService.patch('/api/glance/images/' + image.id + '/', image)
-        .error(function () {
+        .catch(function onError() {
           toastService.add('error', gettext('Unable to update the image.'));
         });
     }
@@ -248,7 +250,7 @@
     function deleteImage(imageId, suppressError) {
       var promise = apiService.delete('/api/glance/images/' + imageId + '/');
 
-      return suppressError ? promise : promise.error(function() {
+      return suppressError ? promise : promise.catch(function onError() {
         var msg = gettext('Unable to delete the image with id: %(id)s');
         toastService.add('error', interpolate(msg, { id: imageId }, true));
       });
@@ -263,7 +265,7 @@
      */
     function getImageProps(id) {
       return apiService.get('/api/glance/images/' + id + '/properties/')
-        .error(function () {
+        .catch(function onError() {
           toastService.add('error', gettext('Unable to retrieve the image custom properties.'));
         });
     }
@@ -278,6 +280,10 @@
      * @returns {Object} The result of the API call
      */
     function editImageProps(id, updated, removed) {
+      angular.forEach(READONLY_PROPERTIES, function(key) {
+        delete updated[key];
+      });
+
       return apiService.patch(
         '/api/glance/images/' + id + '/properties/',
         {
@@ -285,7 +291,7 @@
           removed: removed
         }
       )
-      .error(function () {
+      .catch(function onError() {
         toastService.add('error', gettext('Unable to edit the image custom properties.'));
       });
     }
@@ -328,7 +334,7 @@
     function getImages(params) {
       var config = params ? { 'params' : params} : {};
       return apiService.get('/api/glance/images/', config)
-        .error(function () {
+        .catch(function onError() {
           toastService.add('error', gettext('Unable to retrieve the images.'));
         });
     }
@@ -397,7 +403,7 @@
 
       var promise = apiService.get('/api/glance/metadefs/namespaces/', config);
 
-      return suppressError ? promise : promise.error(function() {
+      return suppressError ? promise : promise.catch(function onError() {
         toastService.add('error', gettext('Unable to retrieve the namespaces.'));
       });
     }
@@ -423,7 +429,7 @@
 
       return apiService
         .get('/api/glance/metadefs/resourcetypes/', config)
-        .error(function() {
+        .catch(function onError() {
           toastService.add('error', gettext('Unable to retrieve the resource types.'));
         });
     }
