@@ -131,17 +131,47 @@ horizon.network_topology = {
         self.delete_balloon();
       });
 
-    angular.element('#toggle_labels').change(function() {
+    angular.element('#toggle_labels').on('change', function() {
       horizon.cookies.put('show_labels', this.checked);
       self.refresh_labels();
     });
 
-    angular.element('#toggle_networks').change(function() {
+    angular.element('#toggle_networks').on('change', function() {
       horizon.cookies.put('are_networks_collapsed', this.checked);
       self.refresh_networks();
       self.refresh_labels();
     });
 
+    angular.element('#center_topology').on('click', function() {
+     this.blur(); // remove btn focus after click
+     self.delete_balloon();
+      // move visualization to the center and reset scale
+      self.vis.transition()
+        .duration(1500)
+        .attr('transform', 'translate(0,0)scale(1)');
+
+      // reset internal zoom translate and scale parameters so on next
+      // move the objects do not jump to the old position
+      self.zoom.translate([0,0]);
+      self.zoom.scale(1);
+      self.translate = null;
+    });
+    angular.element(window).on('message', function(e) {
+        var message = JSON.parse(e.originalEvent.data);
+        if (self.previous_message !== message.message) {
+          horizon.alert(message.type, message.message);
+          self.previous_message = message.message;
+          self.delete_post_message(message.iframe_id);
+          if (message.type == 'success' && self.deleting_device) {
+            self.remove_node_on_delete();
+          }
+          self.retrieve_network_info();
+          setTimeout(function() {
+            self.previous_message = null;
+          },10000);
+        }
+      });
+
     // set up loader first thing
     self.$loading_template.show();
 
@@ -1037,6 +1067,9 @@ horizon.network_topology = {
       htmlData.subnet = subnets;
       if (d instanceof Network) {
         htmlData.delete_label = gettext('Delete Network');
+        if (d.allow_delete_subnet){
+          htmlData.allow_delete_subnet = d.allow_delete_subnet;
+        }
       }
       htmlData.add_subnet_url = 'network/' + d.id + '/subnet/create';
       htmlData.add_subnet_label = gettext('Create Subnet');
@@ -1068,19 +1101,19 @@ horizon.network_topology = {
         })
         .addClass('leftPosition');
     }
-    _balloon.find('.delete-device').click(function() {
+    _balloon.find('.delete-device').on('click', function() {
       var _this = angular.element(this);
       var delete_modal = horizon.datatables.confirm(_this);
-      delete_modal.find('.btn.btn-danger').click(function () {
+      delete_modal.find('.btn.btn-danger').on('click', function () {
         _this.prop('disabled', true);
         d3.select('#id_' + _this.data('device-id')).classed('loading',true);
         self.delete_device(_this.data('type'),_this.data('device-id'));
       });
     });
-    _balloon.find('.delete-port').click(function() {
+    _balloon.find('.delete-port').on('click', function() {
       var _this = angular.element(this);
       var delete_modal = horizon.datatables.confirm(_this);
-      delete_modal.find('.btn.btn-danger').click(function () {
+      delete_modal.find('.btn.btn-danger').on('click', function () {
         _this.prop('disabled', true);
         self.delete_port(_this.data('router-id'),_this.data('port-id'),_this.data('network-id'));
       });
