@@ -9,7 +9,12 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+
+import time
+
 import netaddr
+
+from selenium.common import exceptions
 from selenium.webdriver.common import by
 
 from openstack_dashboard.test.integration_tests.pages import basepage
@@ -64,13 +69,24 @@ class InstancesPage(basepage.BaseNavigationPage):
     FLAVOR_STEP_INDEX = 2
     NETWORKS_STEP_INDEX = 3
 
+    _search_state_active = (
+        by.By.XPATH,
+        "//*[contains(@class,'normal_column')][contains(text(),'Active')]"
+    )
+
     def __init__(self, driver, conf):
         super().__init__(driver, conf)
         self._page_title = "Instances"
 
     def _get_row_with_instance_name(self, name):
-        return self.instances_table.get_row(self.INSTANCES_TABLE_NAME_COLUMN,
-                                            name)
+        for attempt in range(4):
+            row = self.instances_table.get_row(
+                self.INSTANCES_TABLE_NAME_COLUMN, name)
+            if row is not None:
+                return row
+            else:
+                time.sleep(0.5)
+        return None
 
     def _get_rows_with_instances_names(self, names):
         return [
@@ -91,6 +107,7 @@ class InstancesPage(basepage.BaseNavigationPage):
             instance_count=DEFAULT_COUNT,
             flavor=DEFAULT_FLAVOR,
             boot_source=DEFAULT_BOOT_SOURCE,
+            network_type=DEFAULT_NETWORK_TYPE,
             source_name=None,
             device_size=None,
             vol_delete_on_instance_delete=DEFAULT_VOL_DELETE_ON_INSTANCE_DELETE
@@ -155,6 +172,10 @@ class InstancesPage(basepage.BaseNavigationPage):
             row = self._get_row_with_instance_name(name)
             return row and row.cells[self.INSTANCES_TABLE_STATUS_COLUMN]
 
+        try:
+            self.wait_until_element_is_visible(self._search_state_active)
+        except exceptions.TimeoutException:
+            return False
         status = self.instances_table.wait_cell_status(cell_getter,
                                                        ('Active', 'Error'))
         return status == 'Active'
@@ -177,6 +198,6 @@ class InstancesPage(basepage.BaseNavigationPage):
     def get_fixed_ipv4(self, name):
         row = self._get_row_with_instance_name(name)
         ips = row.cells[self.INSTANCES_TABLE_IP_COLUMN].text
-        for ip in ips.split():
+        for ip in ips.split(','):
             if netaddr.valid_ipv4(ip):
                 return ip
