@@ -16,21 +16,20 @@ from openstack_dashboard.test.integration_tests.regions import forms
 from openstack_dashboard.test.integration_tests.regions import tables
 
 
+class UsageTable(tables.TableRegion):
+    name = 'project_usage'
+
+
 class OverviewPage(basepage.BaseNavigationPage):
-    _usage_table_locator = (by.By.ID, 'project_usage')
     _date_form_locator = (by.By.ID, 'date_form')
 
-    USAGE_TABLE_ACTIONS = ("download_csv",)
-
     def __init__(self, driver, conf):
-        super(OverviewPage, self).__init__(driver, conf)
+        super().__init__(driver, conf)
         self._page_title = 'Instance Overview'
 
     @property
     def usage_table(self):
-        src_elem = self._get_element(*self._usage_table_locator)
-        return tables.ActionsTableRegion(self.driver, self.conf, src_elem,
-                                         self.USAGE_TABLE_ACTIONS)
+        return UsageTable(self.driver, self.conf)
 
     @property
     def date_form(self):
