@@ -19,13 +19,14 @@ class TestDashboardHelp(helpers.TestCase):
         """Verifies Help link redirects to the right URL."""
 
         self.home_pg.go_to_help_page()
-        self.home_pg._wait_until(
-            lambda _: self.home_pg.is_nth_window_opened(2))
+        self.home_pg._wait_until(lambda _: self.home_pg.is_nth_window_opened(2)
+                                 )
         self.home_pg.switch_window()
+        self.home_pg.is_help_page()
 
-        self.assertEqual(self.CONFIG.dashboard.help_url,
-                         self.home_pg.get_url_current_page(),
-                         "help link did not redirect to the right URL")
+        self.assertIn(self.CONFIG.dashboard.help_url,
+                      self.home_pg.get_url_current_page(),
+                      "help link did not redirect to the right URL")
 
         self.home_pg.close_window()
         self.home_pg.switch_window()
@@ -48,7 +49,22 @@ class TestPasswordChange(helpers.TestCase):
 
     def _reset_password(self):
         passwordchange_page = self.home_pg.go_to_settings_changepasswordpage()
-        passwordchange_page.reset_to_default_password(self.NEW_PASSWORD)
+        # Per unique_last_password policy, we need to do unique password reset
+        # before resetting default password.
+        unique_last_password_count = int(
+            self.CONFIG.identity.unique_last_password_count)
+        old_password = int(self.NEW_PASSWORD)
+        for x in range(1, unique_last_password_count):
+            new_password = old_password + 1
+            passwordchange_page = self.home_pg.\
+                go_to_settings_changepasswordpage()
+            passwordchange_page.change_password(
+                str(old_password), str(new_password))
+            self.home_pg = self.login_pg.login(
+                user=self.TEST_USER_NAME, password=new_password)
+            old_password = new_password
+        passwordchange_page = self.home_pg.go_to_settings_changepasswordpage()
+        passwordchange_page.reset_to_default_password(old_password)
 
     def _login(self):
         self.login_pg.login()
@@ -64,8 +80,8 @@ class TestPasswordChange(helpers.TestCase):
             passwordchange_page.change_password(self.TEST_PASSWORD,
                                                 self.NEW_PASSWORD)
 
-            self.home_pg = self.login_pg.login(user=self.TEST_USER_NAME,
-                                               password=self.NEW_PASSWORD)
+            self.home_pg = self.login_pg.login(
+                user=self.TEST_USER_NAME, password=self.NEW_PASSWORD)
             self.assertTrue(self.home_pg.is_logged_in,
                             "Failed to login with new password")
         finally:
@@ -84,8 +100,8 @@ class TestPasswordChange(helpers.TestCase):
                 self.login_pg.is_logout_reason_displayed(),
                 "The logout reason message was not found on the login page")
         finally:
-            self.login_pg.login(user=self.TEST_USER_NAME,
-                                password=self.NEW_PASSWORD)
+            self.login_pg.login(
+                user=self.TEST_USER_NAME, password=self.NEW_PASSWORD)
             self._reset_password()
             self._login()
 
@@ -99,13 +115,14 @@ class TestUserSettings(helpers.TestCase):
 
         user_settings = (("Language", changed_settings["language"], language),
                          ("Timezone", changed_settings["timezone"], timezone),
-                         ("Pagesize", changed_settings["pagesize"], pagesize),
-                         ("Loglines", changed_settings["loglines"], loglines))
+                         ("Pagesize", changed_settings["pagesize"],
+                          pagesize), ("Loglines", changed_settings["loglines"],
+                                      loglines))
 
         for (setting, expected, observed) in user_settings:
-            self.assertEqual(expected, observed,
-                             "expected %s: %s, instead found: %s"
-                             % (setting, expected, observed))
+            self.assertEqual(
+                expected, observed, "expected %s: %s, instead found: %s" %
+                (setting, expected, observed))
 
     def test_user_settings_change(self):
         """tests the user's settings options:
@@ -117,33 +134,28 @@ class TestUserSettings(helpers.TestCase):
         * verifies all changes were successfully executed
         """
         settings_page = self.home_pg.go_to_settings_usersettingspage()
-
         settings_page.change_language("es")
-        self.assertTrue(
-            settings_page.find_message_and_dismiss(messages.SUCCESS))
-        self.assertFalse(
-            settings_page.find_message_and_dismiss(messages.ERROR))
+        self.assertEqual(
+            settings_page.find_messages_and_dismiss(), {messages.SUCCESS})
 
         settings_page.change_timezone("Asia/Jerusalem")
-        self.assertTrue(
-            settings_page.find_message_and_dismiss(messages.SUCCESS))
-        self.assertFalse(
-            settings_page.find_message_and_dismiss(messages.ERROR))
+        self.assertEqual(
+            settings_page.find_messages_and_dismiss(), {messages.SUCCESS})
 
         settings_page.change_pagesize("30")
-        self.assertTrue(
-            settings_page.find_message_and_dismiss(messages.SUCCESS))
-        self.assertFalse(
-            settings_page.find_message_and_dismiss(messages.ERROR))
+        self.assertEqual(
+            settings_page.find_messages_and_dismiss(), {messages.SUCCESS})
 
         settings_page.change_loglines("50")
-        self.assertTrue(
-            settings_page.find_message_and_dismiss(messages.SUCCESS))
-        self.assertFalse(
-            settings_page.find_message_and_dismiss(messages.ERROR))
+        self.assertEqual(
+            settings_page.find_messages_and_dismiss(), {messages.SUCCESS})
 
-        changed_settings = {"language": "es", "timezone": "Asia/Jerusalem",
-                            "pagesize": "30", "loglines": "50"}
+        changed_settings = {
+            "language": "es",
+            "timezone": "Asia/Jerusalem",
+            "pagesize": "30",
+            "loglines": "50"
+        }
         self.verify_user_settings_change(settings_page, changed_settings)
 
         settings_page.return_to_default_settings()
