@@ -36,86 +36,129 @@ from openstack_auth import user as auth_user
 from openstack_dashboard.test.test_data import utils
 
 
-# Dummy service catalog with all service.
+# Dummy service catalog with all service. All data should match
+# scoped_auth_ref.service_catalog.catalog from keystoneauth1.
 # All endpoint URLs should point to example.com.
 # Try to keep them as accurate to real data as possible (ports, URIs, etc.)
+# TODO(e0ne): make RegionOne and RegionTwo links unique.
 SERVICE_CATALOG = [
     {"type": "compute",
      "name": "nova",
      "endpoints_links": [],
      "endpoints": [
          {"region": "RegionOne",
-          "adminURL": "http://admin.nova.example.com:8774/v2",
-          "internalURL": "http://int.nova.example.com:8774/v2",
-          "publicURL": "http://public.nova.example.com:8774/v2"},
-         {"region": "RegionTwo",
-          "adminURL": "http://admin.nova2.example.com:8774/v2",
-          "internalURL": "http://int.nova2.example.com:8774/v2",
-          "publicURL": "http://public.nova2.example.com:8774/v2"}]},
-    {"type": "volumev2",
-     "name": "cinderv2",
-     "endpoints_links": [],
-     "endpoints": [
+          "interface": "admin",
+          "url": "http://admin.nova.example.com:8774/v2"},
          {"region": "RegionOne",
-          "adminURL": "http://admin.cinder.example.com:8776/v2",
-          "internalURL": "http://int.cinder.example.com:8776/v2",
-          "publicURL": "http://public.cinder.example.com:8776/v2"},
+          "interface": "internal",
+          "url": "http://int.nova.example.com:8774/v2"},
+         {"region": "RegionOne",
+          "interface": "public",
+          "url": "http://public.nova.example.com:8774/v2"},
          {"region": "RegionTwo",
-          "adminURL": "http://admin.cinder.example.com:8776/v2",
-          "internalURL": "http://int.cinder.example.com:8776/v2",
-          "publicURL": "http://public.cinder.example.com:8776/v2"}]},
+          "interface": "admin",
+          "url": "http://admin.nova2.example.com:8774/v2"},
+         {"region": "RegionTwo",
+          "interface": "internal",
+          "url": "http://int.nova2.example.com:8774/v2"},
+         {"region": "RegionTwo",
+          "interface": "public",
+          "url": "http://public.nova2.example.com:8774/v2"}
+     ]},
     {"type": "volumev3",
      "name": "cinderv3",
      "endpoints_links": [],
      "endpoints": [
          {"region": "RegionOne",
-          "adminURL": "http://admin.cinder.example.com:8776/v3",
-          "internalURL": "http://int.cinder.example.com:8776/v3",
-          "publicURL": "http://public.cinder.example.com:8776/v3"},
+          "interface": "admin",
+          "url": "http://admin.cinder.example.com:8776/v3"},
+         {"region": "RegionOne",
+          "interface": "internal",
+          "url": "http://int.cinder.example.com:8776/v3"},
+         {"region": "RegionOne",
+          "interface": "public",
+          "url": "http://public.cinder.example.com:8776/v3"},
          {"region": "RegionTwo",
-          "adminURL": "http://admin.cinder.example.com:8776/v3",
-          "internalURL": "http://int.cinder.example.com:8776/v3",
-          "publicURL": "http://public.cinder.example.com:8776/v3"}]},
+          "interface": "admin",
+          "url": "http://admin.cinder2.example.com:8776/v3"},
+         {"region": "RegionTwo",
+          "interface": "internal",
+          "url": "http://int.cinder2.example.com:8776/v3"},
+         {"region": "RegionTwo",
+          "interface": "public",
+          "url": "http://public.cinder2.example.com:8776/v3"}
+     ]},
     {"type": "image",
      "name": "glance",
      "endpoints_links": [],
      "endpoints": [
          {"region": "RegionOne",
-          "adminURL": "http://admin.glance.example.com:9292",
-          "internalURL": "http://int.glance.example.com:9292",
-          "publicURL": "http://public.glance.example.com:9292"}]},
+          "interface": "admin",
+          "url": "http://admin.glance.example.com:9292",
+          },
+         {"region": "RegionOne",
+          "interface": "internal",
+          "url": "http://int.glance.example.com:9292"},
+         {"region": "RegionOne",
+          "interface": "public",
+          "url": "http://public.glance.example.com:9292"}
+     ]},
     {"type": "identity",
      "name": "keystone",
      "endpoints_links": [],
      "endpoints": [
          {"region": "RegionOne",
-          "adminURL": "http://admin.keystone.example.com/identity/v3",
-          "internalURL": "http://int.keystone.example.com/identity/v3",
-          "publicURL": "http://public.keystone.example.com/identity/v3"}]},
+          "interface": "admin",
+          "url": "http://admin.keystone.example.com/identity/v3"},
+         {"region": "RegionOne",
+          "interface": "internal",
+          "url": "http://int.keystone.example.com/identity/v3"},
+         {"region": "RegionOne",
+          "interface": "public",
+          "url": "http://public.keystone.example.com/identity/v3"}
+     ]},
     {"type": "object-store",
      "name": "swift",
      "endpoints_links": [],
      "endpoints": [
          {"region": "RegionOne",
-          "adminURL": "http://admin.swift.example.com:8080/",
-          "internalURL": "http://int.swift.example.com:8080/",
-          "publicURL": "http://public.swift.example.com:8080/"}]},
+          "interface": "admin",
+          "url": "http://admin.swift.example.com:8080/"},
+         {"region": "RegionOne",
+          "interface": "internal",
+          "url": "http://int.swift.example.com:8080/"},
+         {"region": "RegionOne",
+          "interface": "public",
+          "url": "http://public.swift.example.com:8080/"}
+     ]},
     {"type": "network",
      "name": "neutron",
      "endpoints_links": [],
      "endpoints": [
          {"region": "RegionOne",
-          "adminURL": "http://admin.neutron.example.com:9696/",
-          "internalURL": "http://int.neutron.example.com:9696/",
-          "publicURL": "http://public.neutron.example.com:9696/"}]},
+          "interface": "admin",
+          "url": "http://admin.neutron.example.com:9696/"},
+         {"region": "RegionOne",
+          "interface": "internal",
+          "url": "http://int.neutron.example.com:9696/"},
+         {"region": "RegionOne",
+          "interface": "public",
+          "url": "http://public.neutron.example.com:9696/"}
+     ]},
     {"type": "ec2",
      "name": "EC2 Service",
      "endpoints_links": [],
      "endpoints": [
          {"region": "RegionOne",
-          "adminURL": "http://admin.nova.example.com:8773/services/Admin",
-          "publicURL": "http://public.nova.example.com:8773/services/Cloud",
-          "internalURL": "http://int.nova.example.com:8773/services/Cloud"}]},
+          "interface": "admin",
+          "url": "http://admin.nova.example.com:8773/services/Admin"},
+         {"region": "RegionOne",
+          "interface": "public",
+          "url": "http://public.nova.example.com:8773/services/Cloud"},
+         {"region": "RegionOne",
+          "interface": "internal",
+          "url": "http://int.nova.example.com:8773/services/Cloud"}
+     ]},
 ]
 
 
@@ -339,7 +382,7 @@ def data(TEST):
                      'domain_id': '2',
                      'domain_name': 'disabled_domain'}
     tenant_dict_3 = {'id': "3",
-                     'name': u'\u4e91\u89c4\u5219',
+                     'name': '\u4e91\u89c4\u5219',
                      'description': "an unicode-named tenant.",
                      'enabled': True,
                      'domain_id': '2',
